@@ -28,12 +28,10 @@
 extern "C" {
 #endif
 
-extern void HAIKU_PumpEvents(_THIS);
+extern void HAIKU_PumpEvents(SDL_VideoDevice *_this);
 
 #ifdef __cplusplus
 }
 #endif
 
 #endif
-
-/* vi: set ts=4 sw=4 expandtab: */
